@@ -3,6 +3,7 @@ import json
 import pkg_resources
 
 BASE_DIR = os.environ['BASE_DIR']
+BASE_URL_CSS = "https://static.snoweb.fr/snowebsvg/dist/css/"
 
 try:
     #  Production part
@@ -15,7 +16,3 @@ except pkg_resources.DistributionNotFound:
 
 SVG_DEFAULT_THEME = 'dark'
 SVG_DEFAULT_SIZE = 'x3'
-
-import pdb
-
-pdb.set_trace()
